searchData={"items":[{"type":"module","title":"Enumx","doc":"","ref":"Enumx.html"},{"type":"function","title":"Enumx.all_equal?/1","doc":"Returns `true` if all elements in `enumerable` are equal.","ref":"Enumx.html#all_equal?/1"},{"type":"function","title":"Enumx.do_swap/3","doc":"","ref":"Enumx.html#do_swap/3"},{"type":"function","title":"Enumx.filter_value/2","doc":"Similar to filter/2, but returns the value of the function invocation instead of the element itself","ref":"Enumx.html#filter_value/2"},{"type":"macro","title":"Enumx.is_plain_map/1","doc":"","ref":"Enumx.html#is_plain_map/1"},{"type":"function","title":"Enumx.join/3","doc":"","ref":"Enumx.html#join/3"},{"type":"function","title":"Enumx.shift_first_match_left/3","doc":"","ref":"Enumx.html#shift_first_match_left/3"},{"type":"function","title":"Enumx.shift_first_match_left!/3","doc":"","ref":"Enumx.html#shift_first_match_left!/3"},{"type":"function","title":"Enumx.shift_first_match_right/3","doc":"","ref":"Enumx.html#shift_first_match_right/3"},{"type":"function","title":"Enumx.shift_first_match_right!/3","doc":"","ref":"Enumx.html#shift_first_match_right!/3"},{"type":"function","title":"Enumx.shift_left_by_index/2","doc":"","ref":"Enumx.html#shift_left_by_index/2"},{"type":"function","title":"Enumx.shift_left_by_index!/2","doc":"","ref":"Enumx.html#shift_left_by_index!/2"},{"type":"function","title":"Enumx.shift_right_by_index/2","doc":"","ref":"Enumx.html#shift_right_by_index/2"},{"type":"function","title":"Enumx.shift_right_by_index!/2","doc":"","ref":"Enumx.html#shift_right_by_index!/2"},{"type":"function","title":"Enumx.swap/3","doc":"","ref":"Enumx.html#swap/3"},{"type":"function","title":"Enumx.swap!/3","doc":"","ref":"Enumx.html#swap!/3"},{"type":"function","title":"Enumx.unique_value!/1","doc":"Returns the single unique element if all elements in enumerable are equal; otherwise, raises an error.","ref":"Enumx.html#unique_value!/1"},{"type":"function","title":"Enumx.with_index_length/2","doc":"Returns tuples of each element, its index, and the total length of the enumerable.","ref":"Enumx.html#with_index_length/2"},{"type":"function","title":"Enumx.with_value/2","doc":"Returns each element and the result of a function taking the element. A static value can also be added to each element.","ref":"Enumx.html#with_value/2"},{"type":"extras","title":"Enumx","doc":"# Enumx\n\nAdditional utility functions to extend the power of Elixir's Enum module.\n\n## `filter_value/2`\n\nSimilar to `filter/2`, but returns the value of the function invocation instead of the element itself.\n\n```elixir\nassert Enumx.filter_value([1, 2, 3, 4, 5], &(&1 > 3 && &1 * 2)) == [8, 10]\n\nassert Enumx.filter_value([foo: 1, bar: 2, baz: 3], fn {k, v} -> v > 1 && k end) == [:bar, :baz]\n\nassert Enumx.filter_value(%{foo: 1, bar: 2, baz: 3}, fn {k, v} -> v > 1 && k end) == [:bar, :baz]\n```\n\n## `all_equal?/1`\n\nReturns `true` if all elements in `enumerable` are equal.\n\n```elixir\nassert Enumx.all_equal?([1, 1])\n\nassert Enumx.all_equal?([foo: 1, foo: 1])\n```\n\n## `unique_value!/1`\n\nReturns the single unique element if all elements in enumerable are equal; otherwise, raises an error.\n\n```elixir\nassert Enumx.unique_value!([1, 1]) == 1\n\nassert Enumx.unique_value!(%{foo: 1}) == {:foo, 1}\n\nassert Enumx.unique_value!([foo: 1, foo: 1]) == {:foo, 1}\n\nassert_raise ArgumentError, fn ->\n  Enumx.unique_value!([]) # raises error: cannot call `unique_value!/1` on an empty list\nend\n\nassert_raise RuntimeError, fn ->\n  Enumx.unique_value!([1, 2]) # raises error: elements in the list [1, 2] are not equal\nend\n```\n\n## `is_plain_map/1`\n\nDetermines if the given term is a plain map (not a struct). It can be as a guard clause.\n\n```elixir\nassert Enumx.is_plain_map(%{}) == true\nassert Enumx.is_plain_map(%MyStruct{}) == false\nassert Enumx.is_plain_map(1..5) == false\n```\n\n## `shift_left_by_index/2` and `shift_left_by_index!/2`\n\nShifts the element at the given index one position to the left.\n\n```elixir\nassert Enumx.shift_left_by_index([1, 2, 3], 1) == {:ok, [2, 1, 3], :shifted}\n```\n\n## `shift_right_by_index/2` and `shift_right_by_index!/2`\n\nShifts the element at the given index one position to the right.\n\n```elixir\nassert Enumx.shift_right_by_index([1, 2, 3], 1) == {:ok, [1, 3, 2], :shifted}\n```\n\n## `shift_first_match_left/3` and `shift_first_match_left!/3`\n\nShifts the first element that matches the comparison function one position to the left.\n\n```elixir\nassert Enumx.shift_first_match_left([1, 2, 3], 2, &(&1 == &2)) == {:ok, [2, 1, 3], :shifted}\n```\n\n## `shift_first_match_right/3` and `shift_first_match_right!/3`\n\nShifts the first element that matches the comparison function one position to the right.\n\n```elixir\nassert Enumx.shift_first_match_right([1, 2, 3], 2, &(&1 == &2)) == {:ok, [1, 3, 2], :shifted}\n```\n\n## `swap/3` and `swap!/3`\n\nSwaps the elements at the given indices.\n\n```elixir\nassert Enumx.swap([1, 2, 3], 0, 2) == {:ok, [3, 2, 1], :swapped}\n```\n\n## `join/3`\n\nJoins the elements of a list into a string, using the specified delimiter between elements and a different delimiter before the last element. This function is useful for formatting lists of items in natural language.\n\n```elixir\nassert \"foo, bar and baz\" == Enumx.join([\"foo\", \"bar\", \"baz\"], \", \", \" and \")\nassert \"foo and bar\" == Enumx.join([\"foo\", \"bar\"], \", \", \" and \")\nassert \"foo\" == Enumx.join([\"foo\"], \", \", \" and \")\nassert \"\" == Enumx.join([], \", \", \" and \")\n```\n\n## `with_index_length/2`\n\nReturns tuples of each element, its index, and the total length of the enumerable.\n\n```elixir\nassert [{:foo, 0, 3}, {:bar, 1, 3}, {:baz, 2, 3}] ==\n          Enumx.with_index_length([:foo, :bar, :baz])\n\nassert [{:foo, 5, 3}, {:bar, 6, 3}, {:baz, 7, 3}] ==\n          Enumx.with_index_length([:foo, :bar, :baz], 5)\n\nassert [{3, 0, :foo}, {3, 1, :bar}, {3, 2, :baz}] ==\n          Enumx.with_index_length([:foo, :bar, :baz], fn el, i, length -> {length, i, el} end)\n```\n\n## `with_value/2`\n\nReturns each element and the result of a function taking the element. A static value can also be added to each element.\n\n```elixir\nassert [{\"foo\", \"oof\"}, {\"bar\", \"rab\"}, {\"baz\", \"zab\"}] ==\n          Enumx.with_value([\"foo\", \"bar\", \"baz\"], &String.reverse/1)\n```\n\nThis function adds semantics and reduces special characters, ideal for keeping code clear when used in templates, compared with the Enum.map equivalent:\n\n```elixir\nassert [{\"foo\", \"oof\"}, {\"bar\", \"rab\"}, {\"baz\", \"zab\"}] ==\n          Enum.map([\"foo\", \"bar\", \"baz\"], &{&1, String.reverse(&1)})\n```","ref":"readme.html"},{"type":"extras","title":"Installation - Enumx","doc":"Add `enumx` for Elixir as a dependency in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:enumx, \"~> 0.7\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"HexDocs - Enumx","doc":"HexDocs documentation can be found at [https://hexdocs.pm/enumx](https://hexdocs.pm/enumx).","ref":"readme.html#hexdocs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}